EXPORTS
	??0CSmsTestBase@@IAE@AAVCSmsTestUtils@@ABVTDesC16@@AAHH@Z @ 1 NONAME ; protected: __thiscall CSmsTestBase::CSmsTestBase(class CSmsTestUtils &,class TDesC16 const &,int &,int)
	??0CSmsTestUtils@@IAE@AAVRTest@@@Z @ 2 NONAME ; protected: __thiscall CSmsTestUtils::CSmsTestUtils(class RTest &)
	??1CSmsTestBase@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CSmsTestBase::~CSmsTestBase(void)
	??1CSmsTestUtils@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CSmsTestUtils::~CSmsTestUtils(void)
	?AddRecipientL@CSmsTestUtils@@QAEXJABVTDesC16@@@Z @ 5 NONAME ; public: void __thiscall CSmsTestUtils::AddRecipientL(long,class TDesC16 const &)
	?AddSystemAgentConditionsL@CSmsTestUtils@@QAEXXZ @ 6 NONAME ; public: void __thiscall CSmsTestUtils::AddSystemAgentConditionsL(void)
	?AreMessagesSameTextL@CSmsTestUtils@@QAEHJJH@Z @ 7 NONAME ; public: int __thiscall CSmsTestUtils::AreMessagesSameTextL(long,long,int)
	?ClearLogL@CSmsTestBase@@IAEXXZ @ 8 NONAME ; protected: void __thiscall CSmsTestBase::ClearLogL(void)
	?ConstructL@CSmsTestUtils@@MAEXI@Z @ 9 NONAME ; protected: virtual void __thiscall CSmsTestUtils::ConstructL(unsigned int)
	?CreateDummyMessageToReceiveL@CSmsTestUtils@@QAEJXZ @ 10 NONAME ; public: long __thiscall CSmsTestUtils::CreateDummyMessageToReceiveL(void)
	?CreateDummyMessageToSendL@CSmsTestUtils@@QAEJXZ @ 11 NONAME ; public: long __thiscall CSmsTestUtils::CreateDummyMessageToSendL(void)
	?CreateMessageL@CSmsTestUtils@@QAEXJAAVTMsvEntry@@AAVCSmsHeader@@AAVCRichText@@ABVTTime@@@Z @ 12 NONAME ; public: void __thiscall CSmsTestUtils::CreateMessageL(long,class TMsvEntry &,class CSmsHeader &,class CRichText &,class TTime const &)
	?CreateSmsServerMtmRegL@CSmsTestUtils@@QAEXXZ @ 13 NONAME ; public: void __thiscall CSmsTestUtils::CreateSmsServerMtmRegL(void)
	?CreateSmsServiceL@CSmsTestUtils@@QAEJXZ @ 14 NONAME ; public: long __thiscall CSmsTestUtils::CreateSmsServiceL(void)
	?DeleteSmsMessagesL@CSmsTestUtils@@QAEXJ@Z @ 15 NONAME ; public: void __thiscall CSmsTestUtils::DeleteSmsMessagesL(long)
	?DeleteSmsServiceL@CSmsTestUtils@@QAEXXZ @ 16 NONAME ; public: void __thiscall CSmsTestUtils::DeleteSmsServiceL(void)
	?DisplayLogL@CSmsTestBase@@IAEXXZ @ 17 NONAME ; protected: void __thiscall CSmsTestBase::DisplayLogL(void)
	?DisplayMessageL@CSmsTestUtils@@QAEXJ@Z @ 18 NONAME ; public: void __thiscall CSmsTestUtils::DisplayMessageL(long)
	?DisplayMessagesL@CSmsTestUtils@@QAEXABVCMsvEntrySelection@@@Z @ 19 NONAME ; public: void __thiscall CSmsTestUtils::DisplayMessagesL(class CMsvEntrySelection const &)
	?DisplaySendingStatesL@CSmsTestUtils@@QAEXABVCMsvEntrySelection@@@Z @ 20 NONAME ; public: void __thiscall CSmsTestUtils::DisplaySendingStatesL(class CMsvEntrySelection const &)
	?DoTestSchedulingL@CSmsTestBase@@MAEXABVTDesC16@@HVTTimeIntervalSeconds@@@Z @ 21 NONAME ; protected: virtual void __thiscall CSmsTestBase::DoTestSchedulingL(class TDesC16 const &,int,class TTimeIntervalSeconds)
	?DoTestSendingL@CSmsTestBase@@MAEXABVTDesC16@@H@Z @ 22 NONAME ; protected: virtual void __thiscall CSmsTestBase::DoTestSendingL(class TDesC16 const &,int)
	?FindExistingServicesL@CSmsTestUtils@@UAEXXZ @ 23 NONAME ; public: virtual void __thiscall CSmsTestUtils::FindExistingServicesL(void)
	?FindExistingSmsServiceL@CSmsTestUtils@@QAEJXZ @ 24 NONAME ; public: long __thiscall CSmsTestUtils::FindExistingSmsServiceL(void)
	?GetHeaderLC@CSmsTestUtils@@QAEPAVCSmsHeader@@J@Z @ 25 NONAME ; public: class CSmsHeader * __thiscall CSmsTestUtils::GetHeaderLC(long)
	?InstallSmsMtmGroupL@CSmsTestUtils@@QAEXXZ @ 26 NONAME ; public: void __thiscall CSmsTestUtils::InstallSmsMtmGroupL(void)
	?InstantiateSmsClientMtmL@CSmsTestUtils@@QAEXXZ @ 27 NONAME ; public: void __thiscall CSmsTestUtils::InstantiateSmsClientMtmL(void)
	?InstantiateSmsServerMtmL@CSmsTestUtils@@QAEXXZ @ 28 NONAME ; public: void __thiscall CSmsTestUtils::InstantiateSmsServerMtmL(void)
	?NewL@CSmsTestUtils@@SAPAV1@AAVRTest@@I@Z @ 29 NONAME ; public: static class CSmsTestUtils * __cdecl CSmsTestUtils::NewL(class RTest &,unsigned int)
	?NewLC@CSmsTestUtils@@SAPAV1@AAVRTest@@I@Z @ 30 NONAME ; public: static class CSmsTestUtils * __cdecl CSmsTestUtils::NewLC(class RTest &,unsigned int)
	?Panic@CSmsTestUtils@@IAEXW4TSmsTestUtilsPanic@@@Z @ 31 NONAME ; protected: void __thiscall CSmsTestUtils::Panic(enum TSmsTestUtilsPanic)
	?Panic@CSmsTestUtils@@MAEXH@Z @ 32 NONAME ; protected: virtual void __thiscall CSmsTestUtils::Panic(int)
	?ReadScriptL@CSmsTestUtils@@QAEHABVTDesC16@@JAAVCMsvEntrySelection@@ABVTTime@@@Z @ 33 NONAME ; public: int __thiscall CSmsTestUtils::ReadScriptL(class TDesC16 const &,long,class CMsvEntrySelection &,class TTime const &)
	?Reset@CSmsTestUtils@@UAEXXZ @ 34 NONAME ; public: virtual void __thiscall CSmsTestUtils::Reset(void)
	?RunError@CSmsTestBase@@MAEHH@Z @ 35 NONAME ; protected: virtual int __thiscall CSmsTestBase::RunError(int)
	?SaveBodyToFileL@CSmsTestUtils@@QAEXJ@Z @ 36 NONAME ; public: void __thiscall CSmsTestUtils::SaveBodyToFileL(long)
	?SendingCompleteL@CSmsTestUtils@@QAEHABVCMsvEntrySelection@@AAH@Z @ 37 NONAME ; public: int __thiscall CSmsTestUtils::SendingCompleteL(class CMsvEntrySelection const &,int &)
	?SetCommDbServiceCenterFromScriptL@CSmsTestUtils@@QAEXABVTDesC16@@@Z @ 38 NONAME ; public: void __thiscall CSmsTestUtils::SetCommDbServiceCenterFromScriptL(class TDesC16 const &)
	?StartL@CSmsTestBase@@UAEXXZ @ 39 NONAME ; public: virtual void __thiscall CSmsTestBase::StartL(void)
	?DoTestForwardMsgL@CSmsTestBase@@MAEXJ@Z @ 40 NONAME ; protected: virtual void __thiscall CSmsTestBase::DoTestForwardMsgL(long)
	?DoTestSendMesssageL@CSmsTestBase@@MAEXJ@Z @ 41 NONAME ; protected: virtual void __thiscall CSmsTestBase::DoTestSendMesssageL(long)
	?NotifySaPhoneOnL@CSmsTestUtils@@QAEXXZ @ 42 NONAME ; public: void __thiscall CSmsTestUtils::NotifySaPhoneOnL(void)
	?WaitForInitializeL@CSmsTestUtils@@QAEXXZ @ 43 NONAME ; public: void __thiscall CSmsTestUtils::WaitForInitializeL(void)
	?NotifySaPhoneOffL@CSmsTestUtils@@QAEXXZ @ 44 NONAME ; public: void __thiscall CSmsTestUtils::NotifySaPhoneOffL(void)
	?CompareEmsIE@EmsTestUtils@@YAHABVCEmsInformationElement@@0@Z @ 45 NONAME ; int __cdecl EmsTestUtils::CompareEmsIE(class CEmsInformationElement const &,class CEmsInformationElement const &)
	?CompareEmsMsgL@EmsTestUtils@@YAHABVCSmsMessage@@0@Z @ 46 NONAME ; int __cdecl EmsTestUtils::CompareEmsMsgL(class CSmsMessage const &,class CSmsMessage const &)
	?CreateAnimationL@EmsTestUtils@@YAPAVCEmsAnimationIE@@H@Z @ 47 NONAME ; class CEmsAnimationIE * __cdecl EmsTestUtils::CreateAnimationL(int)
	?CreatePictureL@EmsTestUtils@@YAPAVCEmsPictureIE@@H@Z @ 48 NONAME ; class CEmsPictureIE * __cdecl EmsTestUtils::CreatePictureL(int)
	?FindElementL@EmsTestUtils@@YAPBVCEmsInformationElement@@ABVCSmsMessage@@W4TSmsInformationElementIdentifier@CSmsInformationElement@@@Z @ 49 NONAME ; class CEmsInformationElement const * __cdecl EmsTestUtils::FindElementL(class CSmsMessage const &,enum CSmsInformationElement::TSmsInformationElementIdentifier)

